JBoss Tools SVN: r25471 - trunk/build.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-10-04 16:24:33 -0400 (Mon, 04 Oct 2010)
New Revision: 25471
Modified:
trunk/build/publishComponentZipToStaging.sh
Log:
support multiple branches of published component zips
Modified: trunk/build/publishComponentZipToStaging.sh
===================================================================
--- trunk/build/publishComponentZipToStaging.sh 2010-10-04 19:59:19 UTC (rev 25470)
+++ trunk/build/publishComponentZipToStaging.sh 2010-10-04 20:24:33 UTC (rev 25471)
@@ -3,8 +3,8 @@
if [[ $1 ]]; then
pattern="$1"
else
- echo "Must run from Hudson or manually specify job name"
- echo "(for offline testing), eg., $0 \"drools|teiid|usage|jbpm\" jbosstools-3.2.0.Beta2.aggregate"
+ echo "Must run from Hudson or manually specify pattern"
+ echo "eg., $0 \"drools|teiid|usage|jbpm\""
exit 1
fi
@@ -16,12 +16,15 @@
JOBNAMEREDUX=${JOB_NAME/-publish}
else
echo "Must run from Hudson or manually specify job name"
- echo "(for offline testing), eg., $0 jbosstools-teiid-designer"
+ echo "(for offline testing), eg., $0 \"drools|teiid|usage|jbpm\" jbosstools-3.2.0.Beta2.aggregate"
exit 1
fi
if [[ $DESTINATION == "" ]]; then DESTINATION="tools@filemgmt.jboss.org:/downloads_htdocs/tools"; fi
+# eg., extract 3.2.0.Beta2 from jbosstools-3.2.0.Beta2.aggregate or jbosstools-3.2.0.Beta2.aggregate-publish
+BRANCH=${JOBNAMEREDUX/.aggregate}; BRANCH=${BRANCH/jbosstools-}; #echo $BRANCH
+
# get zip names from zip.list.txt
paths=$(wget -q http://download.jboss.org/jbosstools/builds/staging/${JOBNAMEREDUX}/logs/... -O - | egrep -- "-Update-" | egrep "${pattern}" | sed "s#,\\\\##");
@@ -35,5 +38,5 @@
#echo "Publish ${path} as ${targetZip}"
# to test locally, may need to use --protocol=29 and -P instead of -q
- date; rsync -arzq --rsh=ssh ${targetZip} ${DESTINATION}/updates/staging/
+ date; rsync -arzq --rsh=ssh ${targetZip} ${DESTINATION}/updates/staging/$BRANCH/
done
\ No newline at end of file
14 years, 3 months
JBoss Tools SVN: r25470 - trunk/build.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-10-04 15:59:19 -0400 (Mon, 04 Oct 2010)
New Revision: 25470
Added:
trunk/build/publishComponentZipToStaging.sh
Log:
component publisher for drools, usage, jbpm, etc.
Added: trunk/build/publishComponentZipToStaging.sh
===================================================================
--- trunk/build/publishComponentZipToStaging.sh (rev 0)
+++ trunk/build/publishComponentZipToStaging.sh 2010-10-04 19:59:19 UTC (rev 25470)
@@ -0,0 +1,39 @@
+# Use this script to publish 1 or more component update site zips from an aggregate via a Hudson job
+
+if [[ $1 ]]; then
+ pattern="$1"
+else
+ echo "Must run from Hudson or manually specify job name"
+ echo "(for offline testing), eg., $0 \"drools|teiid|usage|jbpm\" jbosstools-3.2.0.Beta2.aggregate"
+ exit 1
+fi
+
+if [[ $2 ]]; then
+ # specify job to publish on commandline
+ JOBNAMEREDUX=$2
+elif [[ ${JOB_NAME} ]]; then
+ # pull name of the job to publish from the name of the publisher job
+ JOBNAMEREDUX=${JOB_NAME/-publish}
+else
+ echo "Must run from Hudson or manually specify job name"
+ echo "(for offline testing), eg., $0 jbosstools-teiid-designer"
+ exit 1
+fi
+
+if [[ $DESTINATION == "" ]]; then DESTINATION="tools@filemgmt.jboss.org:/downloads_htdocs/tools"; fi
+
+# get zip names from zip.list.txt
+paths=$(wget -q http://download.jboss.org/jbosstools/builds/staging/${JOBNAMEREDUX}/logs/... -O - | egrep -- "-Update-" | egrep "${pattern}" | sed "s#,\\\\##");
+
+for path in $paths; do
+ targetZip=${path##*/};targetZip=${targetZip%%-Update-*}-Update.zip;
+ #echo ""; echo inputPath=$path; echo targetZip=${targetZip}
+
+ #echo "Fetch ${path} as ${targetZip}"
+ # to test locally, may need to use --protocol=29 and -P instead of -q
+ date; rsync -arzq --rsh=ssh ${DESTINATION}/builds/staging/${JOBNAMEREDUX}/${path} ${targetZip}
+
+ #echo "Publish ${path} as ${targetZip}"
+ # to test locally, may need to use --protocol=29 and -P instead of -q
+ date; rsync -arzq --rsh=ssh ${targetZip} ${DESTINATION}/updates/staging/
+done
\ No newline at end of file
Property changes on: trunk/build/publishComponentZipToStaging.sh
___________________________________________________________________
Name: svn:executable
+ *
14 years, 3 months
JBoss Tools SVN: r25469 - branches/jbosstools-3.2.0.Beta1/examples/plugins/org.jboss.tools.project.examples.
by jbosstools-commits@lists.jboss.org
Author: snjeza
Date: 2010-10-04 15:38:52 -0400 (Mon, 04 Oct 2010)
New Revision: 25469
Modified:
branches/jbosstools-3.2.0.Beta1/examples/plugins/org.jboss.tools.project.examples/plugin.properties
branches/jbosstools-3.2.0.Beta1/examples/plugins/org.jboss.tools.project.examples/plugin.xml
Log:
JBIDE-7096 Register new URL for the 3.2 project examples file in JBT & JBDS
Modified: branches/jbosstools-3.2.0.Beta1/examples/plugins/org.jboss.tools.project.examples/plugin.properties
===================================================================
--- branches/jbosstools-3.2.0.Beta1/examples/plugins/org.jboss.tools.project.examples/plugin.properties 2010-10-04 19:25:32 UTC (rev 25468)
+++ branches/jbosstools-3.2.0.Beta1/examples/plugins/org.jboss.tools.project.examples/plugin.properties 2010-10-04 19:38:52 UTC (rev 25469)
@@ -6,4 +6,4 @@
Project_Examples_command =Project Examples...
ProjectExamples=Project Examples file
Project_Examples = Project Examples
-JBoss_Tools_31_Community_Examples = JBoss Tools 3.1 Community Examples
\ No newline at end of file
+JBoss_Tools_32_Community_Examples = JBoss Tools 3.2 Community Examples
\ No newline at end of file
Modified: branches/jbosstools-3.2.0.Beta1/examples/plugins/org.jboss.tools.project.examples/plugin.xml
===================================================================
--- branches/jbosstools-3.2.0.Beta1/examples/plugins/org.jboss.tools.project.examples/plugin.xml 2010-10-04 19:25:32 UTC (rev 25468)
+++ branches/jbosstools-3.2.0.Beta1/examples/plugins/org.jboss.tools.project.examples/plugin.xml 2010-10-04 19:38:52 UTC (rev 25469)
@@ -70,7 +70,7 @@
<extension
point="org.jboss.tools.project.examples.projectExamplesXml"
- name="%JBoss_Tools_31_Community_Examples">
+ name="%JBoss_Tools_32_Community_Examples">
<url>http://download.jboss.org/jbosstools/examples/project-examples-3.2.xml</url>
<experimental>false</experimental>
</extension>
14 years, 3 months
JBoss Tools SVN: r25468 - trunk/build.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-10-04 15:25:32 -0400 (Mon, 04 Oct 2010)
New Revision: 25468
Modified:
trunk/build/publishUpdateZipToStaging.sh
Log:
comment out unnecessary echos (clean Hudson log)
Modified: trunk/build/publishUpdateZipToStaging.sh
===================================================================
--- trunk/build/publishUpdateZipToStaging.sh 2010-10-04 19:24:53 UTC (rev 25467)
+++ trunk/build/publishUpdateZipToStaging.sh 2010-10-04 19:25:32 UTC (rev 25468)
@@ -17,10 +17,10 @@
# get zip name from zip.list.txt
path=$(wget -q http://download.jboss.org/jbosstools/builds/staging/${JOBNAMEREDUX}/logs/... -O - | egrep -- "-Update-" | head -1 | sed "s#,\\\\##");
-echo "Fetch ${path} as ${JOBNAMEREDUX}-Update.zip"
+#echo "Fetch ${path} as ${JOBNAMEREDUX}-Update.zip"
# to test locally, may need to use --protocol=29 and -P instead of -q
date; rsync -arzq --rsh=ssh ${DESTINATION}/builds/staging/${JOBNAMEREDUX}/${path} ${JOBNAMEREDUX}-Update.zip
-echo "Publish ${path} as ${JOBNAMEREDUX}-Update.zip"
+#echo "Publish ${path} as ${JOBNAMEREDUX}-Update.zip"
# to test locally, may need to use --protocol=29 and -P instead of -q
date; rsync -arzq --rsh=ssh ${JOBNAMEREDUX}-Update.zip ${DESTINATION}/updates/staging/
14 years, 3 months
JBoss Tools SVN: r25467 - workspace/examples.
by jbosstools-commits@lists.jboss.org
Author: elvisisking
Date: 2010-10-04 15:24:53 -0400 (Mon, 04 Oct 2010)
New Revision: 25467
Modified:
workspace/examples/project-examples-3.2.xml
Log:
JBIDE-7073 Corrected the name of the project from "Parts Project" to "PartsProject."
Modified: workspace/examples/project-examples-3.2.xml
===================================================================
--- workspace/examples/project-examples-3.2.xml 2010-10-04 19:20:20 UTC (rev 25466)
+++ workspace/examples/project-examples-3.2.xml 2010-10-04 19:24:53 UTC (rev 25467)
@@ -3,7 +3,7 @@
<category>Teiid Designer</category>
<name>Parts</name>
<included-projects>
- Parts Project
+ PartsProject
</included-projects>
<shortDescription>Parts Model Project Set Example</shortDescription>
<description>
14 years, 3 months
JBoss Tools SVN: r25466 - trunk/build.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-10-04 15:20:20 -0400 (Mon, 04 Oct 2010)
New Revision: 25466
Modified:
trunk/build/publishUpdateZipToStaging.sh
Log:
parameterize and rename while downloading (skip a step)
Modified: trunk/build/publishUpdateZipToStaging.sh
===================================================================
--- trunk/build/publishUpdateZipToStaging.sh 2010-10-04 18:55:48 UTC (rev 25464)
+++ trunk/build/publishUpdateZipToStaging.sh 2010-10-04 18:57:44 UTC (rev 25465)
@@ -1,5 +1,7 @@
+# Use this script to publisher a single update site zip via a Hudson job
+
# get zip name from zip.list.txt
-path=$(wget -q http://download.jboss.org/jbosstools/builds/staging/${JOB_NAME}/logs/zip.... -O - | egrep -- "-Update-" | sed "s#,\\\\##");
+path=$(wget -q http://download.jboss.org/jbosstools/builds/staging/${JOB_NAME}/logs/zip.... -O - | egrep -- "-Update-" | head -1 | sed "s#,\\\\##");
# get zip to local
rsync -arzq tools@filemgmt.jboss.org:/downloads_htdocs/tools/builds/staging/${JOB_NAME}/${path} .
@@ -7,4 +9,3 @@
# push renamed zip to remote
cd ${path%/*}; rsync -arzq ${path##*/} tools@filemgmt.jboss.org:/downloads_htdocs/tools/updates/staging/${JOB_NAME}-Update.zip
-
14 years, 3 months
JBoss Tools SVN: r25464 - trunk/build.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-10-04 14:55:48 -0400 (Mon, 04 Oct 2010)
New Revision: 25464
Added:
trunk/build/publishUpdateZipToStaging.sh
Log:
https://jira.jboss.org/browse/JBDS-1349 new single-serving update site zip publisher, for on demand use (by Hudson)
Added: trunk/build/publishUpdateZipToStaging.sh
===================================================================
--- trunk/build/publishUpdateZipToStaging.sh (rev 0)
+++ trunk/build/publishUpdateZipToStaging.sh 2010-10-04 18:55:48 UTC (rev 25464)
@@ -0,0 +1,10 @@
+# get zip name from zip.list.txt
+path=$(wget -q http://download.jboss.org/jbosstools/builds/staging/${JOB_NAME}/logs/zip.... -O - | egrep -- "-Update-" | sed "s#,\\\\##");
+
+# get zip to local
+rsync -arzq tools@filemgmt.jboss.org:/downloads_htdocs/tools/builds/staging/${JOB_NAME}/${path} .
+
+# push renamed zip to remote
+cd ${path%/*}; rsync -arzq ${path##*/} tools@filemgmt.jboss.org:/downloads_htdocs/tools/updates/staging/${JOB_NAME}-Update.zip
+
+
14 years, 3 months
JBoss Tools SVN: r25463 - trunk/build/target-platform.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-10-04 13:36:02 -0400 (Mon, 04 Oct 2010)
New Revision: 25463
Modified:
trunk/build/target-platform/e361-wtp322.target
Log:
update target file w/ newer versionse361-wtp322.target
Modified: trunk/build/target-platform/e361-wtp322.target
===================================================================
--- trunk/build/target-platform/e361-wtp322.target 2010-10-04 16:32:47 UTC (rev 25462)
+++ trunk/build/target-platform/e361-wtp322.target 2010-10-04 17:36:02 UTC (rev 25463)
@@ -1,13 +1,12 @@
-<?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<?pde version="3.6"?>
+<?xml version="1.0" encoding="UTF-8"?><?pde version="3.6"?>
<target includeMode="feature" name="e36-wtp32">
<locations>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="org.maven.ide.eclipse.feature.feature.group" version="0.10.2.20100623-1649"/>
+ <unit version="0.10.2.20100623-1649" id="org.maven.ide.eclipse.feature.feature.group"/>
<repository location="http://m2eclipse.sonatype.org/sites/m2e/"/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="org.maven.ide.eclipse.wtp.feature.feature.group" version="0.10.0.20100209-0800"/>
+ <unit version="0.10.0.20100209-0800" id="org.maven.ide.eclipse.wtp.feature.feature.group"/>
<repository location="http://m2eclipse.sonatype.org/sites/m2e-extras/"/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
@@ -29,9 +28,9 @@
<repository location="http://download.jboss.org/jbosstools/updates/requirements/orbit/R20100519..."/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="javax.wsdl.feature.feature.group" version="1.6.2.v201005080631"/>
- <unit id="org.apache.oro.feature.feature.group" version="2.0.8.v201005080400"/>
- <unit id="org.jdom.feature.feature.group" version="1.0.0.v201005080400"/>
+ <unit version="1.6.2.v201005080631" id="javax.wsdl.feature.feature.group"/>
+ <unit version="2.0.8.v201005080400" id="org.apache.oro.feature.feature.group"/>
+ <unit version="1.0.0.v201005080400" id="org.jdom.feature.feature.group"/>
<repository location="http://download.jboss.org/jbosstools/updates/requirements/thirdparty/"/>
</location>
<!-- <location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
@@ -40,8 +39,8 @@
<repository location="http://download.jboss.org/jbosstools/updates/requirements/xulrunner-1.9.2/"/>
</location> -->
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="org.mozilla.xulrunner.feature.feature.group" version="1.9.12.v20100909-1551-H34-M2"/>
- <unit id="org.mozilla.xpcom.feature.feature.group" version="1.9.12.v20100909-1551-H34-M2"/>
+ <unit version="1.9.12.v20100909-1551-H34-M2" id="org.mozilla.xulrunner.feature.feature.group"/>
+ <unit version="1.9.12.v20100909-1551-H34-M2" id="org.mozilla.xpcom.feature.feature.group"/>
<repository location="http://download.jboss.org/jbosstools/updates/requirements/xulrunner-1.9.1.2/"/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
@@ -51,129 +50,129 @@
<repository location="http://download.eclipse.org/tptp/updates/"/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="org.eclipse.emf.ecore.feature.group" version="2.6.1.v20100914-1218"/>
- <unit id="org.eclipse.emf.feature.group" version="2.6.1.v20100914-1218"/>
- <unit id="org.eclipse.emf.codegen.feature.group" version="2.6.0.v20100914-1218"/>
- <unit id="org.eclipse.emf.common.feature.group" version="2.6.0.v20100914-1218"/>
- <unit id="org.eclipse.emf.databinding.feature.group" version="1.2.0.v20100914-1218"/>
- <unit id="org.eclipse.emf.codegen.ecore.feature.group" version="2.6.1.v20100914-1218"/>
- <unit id="org.eclipse.emf.ecore.edit.feature.group" version="2.6.0.v20100914-1218"/>
- <unit id="org.eclipse.emf.ecore.editor.feature.group" version="2.6.0.v20100914-1218"/>
- <unit id="org.eclipse.emf.ecore.feature.group" version="2.6.1.v20100914-1218"/>
- <unit id="org.eclipse.emf.edit.feature.group" version="2.6.0.v20100914-1218"/>
- <unit id="org.eclipse.xsd.edit.feature.group" version="2.6.0.v20100914-1218"/>
- <unit id="org.eclipse.xsd.feature.group" version="2.6.0.v20100914-1218"/>
+ <unit version="2.6.1.v20100914-1218" id="org.eclipse.emf.ecore.feature.group"/>
+ <unit version="2.6.1.v20100914-1218" id="org.eclipse.emf.feature.group"/>
+ <unit version="2.6.0.v20100914-1218" id="org.eclipse.emf.codegen.feature.group"/>
+ <unit version="2.6.0.v20100914-1218" id="org.eclipse.emf.common.feature.group"/>
+ <unit version="1.2.0.v20100914-1218" id="org.eclipse.emf.databinding.feature.group"/>
+ <unit version="2.6.1.v20100914-1218" id="org.eclipse.emf.codegen.ecore.feature.group"/>
+ <unit version="2.6.0.v20100914-1218" id="org.eclipse.emf.ecore.edit.feature.group"/>
+ <unit version="2.6.0.v20100914-1218" id="org.eclipse.emf.ecore.editor.feature.group"/>
+ <unit version="2.6.1.v20100914-1218" id="org.eclipse.emf.ecore.feature.group"/>
+ <unit version="2.6.0.v20100914-1218" id="org.eclipse.emf.edit.feature.group"/>
+ <unit version="2.6.0.v20100914-1218" id="org.eclipse.xsd.edit.feature.group"/>
+ <unit version="2.6.0.v20100914-1218" id="org.eclipse.xsd.feature.group"/>
<repository location="http://download.eclipse.org/modeling/emf/emf/updates/2.6/R201009141218/"/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="org.eclipse.swtbot.eclipse.feature.group" version="2.0.0.595-dev-e36"/>
- <unit id="org.eclipse.swtbot.eclipse.gef.feature.group" version="2.0.0.595-dev-e36"/>
- <unit id="org.eclipse.swtbot.ide.feature.group" version="2.0.0.595-dev-e36"/>
- <unit id="org.eclipse.swtbot.eclipse.test.junit4.feature.group" version="2.0.0.595-dev-e36"/>
- <unit id="org.eclipse.swtbot.feature.group" version="2.0.0.595-dev-e36"/>
+ <unit version="2.0.0.595-dev-e36" id="org.eclipse.swtbot.eclipse.feature.group"/>
+ <unit version="2.0.0.595-dev-e36" id="org.eclipse.swtbot.eclipse.gef.feature.group"/>
+ <unit version="2.0.0.595-dev-e36" id="org.eclipse.swtbot.ide.feature.group"/>
+ <unit version="2.0.0.595-dev-e36" id="org.eclipse.swtbot.eclipse.test.junit4.feature.group"/>
+ <unit version="2.0.0.595-dev-e36" id="org.eclipse.swtbot.feature.group"/>
<repository location="http://download.eclipse.org/technology/swtbot/helios/dev-build/update-site/"/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="org.eclipse.birt.osgi.runtime.sdk.feature.group" version="2.6.1.v20100617a-57B185wFfAqPz0Ef8mBsMkG-0hfS"/>
- <unit id="org.eclipse.birt.feature.group" version="2.6.1.v20100709a-9iF7A8FGLY4z0pxX3ORrsdrp6JXb"/>
- <unit id="org.eclipse.birt.integration.wtp.feature.group" version="2.6.1.v20100915-1750-35-7w31211A2602861"/>
+ <unit version="2.6.1.v20100617a-57B185wFfAqPz0Ef8mBsMkG-0hfS" id="org.eclipse.birt.osgi.runtime.sdk.feature.group"/>
+ <unit version="2.6.1.v20100709a-9iF7A8FGLY4z0pxX3ORrsdrp6JXb" id="org.eclipse.birt.feature.group"/>
+ <unit version="2.6.1.v20100915-1750-35-7w31211A2602861" id="org.eclipse.birt.integration.wtp.feature.group"/>
<repository location="http://download.eclipse.org/birt/update-site/2.6/"/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="com.ibm.icu.base.feature.group" version="1.1.0.v20090119-79318s73533B57"/>
- <unit id="org.eclipse.equinox.server.core.feature.group" version="1.0.0.v20100510-7K7QErDzbb9z-yqHb55T7I"/>
- <unit id="org.eclipse.cvs.feature.group" version="1.2.0.v20100427-7B77FKt90GE5h0SBT5FV9A01911"/>
- <unit id="org.eclipse.help.feature.group" version="1.2.0.v20100427-7e7jEQFEp4jsWcboLU9l93"/>
- <unit id="org.eclipse.jdt.feature.group" version="3.6.1.r361_v20100714-0800-7z8XFUSFLFlmgLc5z-Bvrt8-HVkH"/>
- <unit id="org.eclipse.platform.feature.group" version="3.6.1.r361_v20100910-9gF78GroFrD9Uh-LhvxMFCV2hCz01p6896L"/>
- <unit id="org.eclipse.platform.ide" version="3.6.1.M20100929-0800"/>
- <unit id="org.eclipse.equinox.executable.feature.group" version="3.4.1.R36x_v20100823-7M7K7JF90dnJ-WLf3cf4yi"/>
- <unit id="org.eclipse.equinox.executable" version="3.4.1.R36x_v20100823-7M7K7JF90dnJ-WLf3cf4yi"/>
- <unit id="org.eclipse.platform.sdk" version="3.6.1.M20100909-0800"/>
- <unit id="org.eclipse.pde.feature.group" version="3.6.1.r361_v20100727-7b7mFL-FET3dhESDgE5_bkJ"/>
- <unit id="org.eclipse.sdk.feature.group" version="3.6.1.r361_v20100714-0800-7Q7m6DDaKf5o53L9dz-d8n-yz-tWdHTE5xVLpsrf4c764"/>
- <unit id="org.eclipse.rcp.feature.group" version="3.6.1.r361_v20100827-9OArFLdFjY-ThSQXmKvKz0_T"/>
- <unit id="org.eclipse.rcp.id" version="3.6.0.M20100909-0800"/>
- <unit id="org.eclipse.rcp.sdk.id" version="3.6.0.M20100929-0800"/>
- <unit id="org.eclipse.releng.tools.feature.group" version="3.3.0.v20100427-44A77w31211642"/>
- <unit id="org.eclipse.sdk.ide" version="3.6.1.M20100929-0800"/>
- <unit id="org.eclipse.sdk.examples.feature.group" version="3.3.0.v20100527-817fFcfFEdcVcRZlgyBRcVX"/>
- <unit id="org.eclipse.sdk.examples.source.feature.group" version="3.3.0.v20100527"/>
- <unit id="org.eclipse.equinox.compendium.sdk.feature.group" version="3.6.0.v20100421-7V7RFiwFLSgEt4Pctn77c7J"/>
- <unit id="org.eclipse.equinox.core.sdk.feature.group" version="3.6.0.v20100603-7sF99FsHFTw8HQBta4g33J3F"/>
- <unit id="org.eclipse.equinox.p2.discovery.feature.feature.group" version="1.0.0.v20100510-4--9oB5855K7P"/>
- <unit id="org.eclipse.equinox.p2.user.ui.feature.group" version="2.0.1.r361_v20100903-897HFZFFZRuSD2LMtVxyz0Vr"/>
- <unit id="org.eclipse.equinox.p2.sdk.feature.group" version="3.6.0.v20100503-9I7VGAeG8tz-BY6jz0w2HLRYr"/>
- <unit id="org.eclipse.equinox.serverside.sdk.feature.group" version="3.6.0.v20100421-7u7NFVgFN5JdPKPhDHd_6Yqc54uw"/>
- <unit id="org.eclipse.equinox.sdk.feature.group" version="3.6.1.r361_v20100903-7H7R07v8rtOZyYbv1I6aZgou5z07"/>
- <unit id="org.eclipse.equinox.weaving.sdk.feature.group" version="1.0.0.v20100421-79--EVVFNFFsFc"/>
- <unit id="org.eclipse.equinox.server.jetty.feature.group" version="1.0.0.v20100510-7I777iBgJ9DIARGH8IIQ"/>
- <unit id="org.eclipse.equinox.server.p2.feature.group" version="1.0.0.v20100503-7x7IFGOFQ74dz0POCNUBjA6L"/>
- <unit id="org.eclipse.pde.api.tools.ee.fragments.feature.group" version="1.0.0.v20100427-7C-7BF9JgLWLMBMMAMsLL"/>
- <unit id="org.eclipse.equinox.p2.ui.admin.rcp.product" version="1.1.0.M20100929-0800"/>
- <unit id="org.eclipse.equinox.server.servletbridge.feature.group" version="1.0.0.v20100510-42A79oB5855K5E"/>
- <unit id="org.eclipse.equinox.server.simple.feature.group" version="1.0.0.v20100510-44DF8s734C48662444"/>
+ <unit version="1.1.0.v20090119-79318s73533B57" id="com.ibm.icu.base.feature.group"/>
+ <unit version="1.0.0.v20100510-7K7QErDzbb9z-yqHb55T7I" id="org.eclipse.equinox.server.core.feature.group"/>
+ <unit version="1.2.0.v20100427-7B77FKt90GE5h0SDT5FV9A01911" id="org.eclipse.cvs.feature.group"/>
+ <unit version="1.2.0.v20100427-7e7jEQFEp4jsWcbqLU9l93" id="org.eclipse.help.feature.group"/>
+ <unit version="3.6.1.r361_v20100714-0800-7z8XFUUFLFlmgLc91IWQa85LVkHD" id="org.eclipse.jdt.feature.group"/>
+ <unit version="3.6.1.r361_v20100910-9gF78GroFrD9Uh-LhvxMFCV2hCz01p6896L" id="org.eclipse.platform.feature.group"/>
+ <unit version="3.6.1.M20100929-0800" id="org.eclipse.platform.ide"/>
+ <unit version="3.4.1.R36x_v20100823-7M7K7JF90dnJ-WLf3cf4yi" id="org.eclipse.equinox.executable.feature.group"/>
+ <unit version="3.4.1.R36x_v20100823-7M7K7JF90dnJ-WLf3cf4yi" id="org.eclipse.equinox.executable"/>
+ <unit version="3.6.1.M20100929-0800" id="org.eclipse.platform.sdk"/>
+ <unit version="3.6.1.r361_v20100727-7b7mFL-FET3dhESDiE5_bkJ" id="org.eclipse.pde.feature.group"/>
+ <unit version="3.6.1.r361_v20100714-0800-7Q7m6DDaKf5o53L9dz-d8n-yz-tWdHTE5xVLpsrf4c764" id="org.eclipse.sdk.feature.group"/>
+ <unit version="3.6.1.r361_v20100827-9OArFLdFjY-ThSQXoKvKz0_T" id="org.eclipse.rcp.feature.group"/>
+ <unit version="3.6.0.M20100929-0800" id="org.eclipse.rcp.id"/>
+ <unit version="3.6.0.M20100929-0800" id="org.eclipse.rcp.sdk.id"/>
+ <unit version="3.3.0.v20100427-44A77w31211642" id="org.eclipse.releng.tools.feature.group"/>
+ <unit version="3.6.1.M20100929-0800" id="org.eclipse.sdk.ide"/>
+ <unit version="3.3.0.v20100527-817fFcfFEdcVcRZlgyBRcVX" id="org.eclipse.sdk.examples.feature.group"/>
+ <unit version="3.3.0.v20100527" id="org.eclipse.sdk.examples.source.feature.group"/>
+ <unit version="3.6.0.v20100421-7V7RFiwFLSgEt4Pctn77c7J" id="org.eclipse.equinox.compendium.sdk.feature.group"/>
+ <unit version="3.6.0.v20100603-7sF99FsHFTw8HQBta4g33J3F" id="org.eclipse.equinox.core.sdk.feature.group"/>
+ <unit version="1.0.0.v20100510-4--9oB5855K7P" id="org.eclipse.equinox.p2.discovery.feature.feature.group"/>
+ <unit version="2.0.1.r361_v20100903-897HFZFFZRuSD2LMtVxyz0Vr" id="org.eclipse.equinox.p2.user.ui.feature.group"/>
+ <unit version="3.6.0.v20100503-9I7VGAeG8tz-BY6jz0w2HLRYr" id="org.eclipse.equinox.p2.sdk.feature.group"/>
+ <unit version="3.6.0.v20100421-7u7NFVgFN5JdPKPhDHd_6Yqc54uw" id="org.eclipse.equinox.serverside.sdk.feature.group"/>
+ <unit version="3.6.1.r361_v20100903-7H7R07v8rtOZyYbv1I6aZgou5z07" id="org.eclipse.equinox.sdk.feature.group"/>
+ <unit version="1.0.0.v20100421-79--EVVFNFFsFc" id="org.eclipse.equinox.weaving.sdk.feature.group"/>
+ <unit version="1.0.0.v20100510-7I777iBgJ9DIARGH8IIQ" id="org.eclipse.equinox.server.jetty.feature.group"/>
+ <unit version="1.0.0.v20100503-7x7IFGOFQ74dz0POCNUBjA6L" id="org.eclipse.equinox.server.p2.feature.group"/>
+ <unit version="1.0.0.v20100427-7C-7BF9JgLWLMBMMAMsLL" id="org.eclipse.pde.api.tools.ee.fragments.feature.group"/>
+ <unit version="1.1.0.M20100929-0800" id="org.eclipse.equinox.p2.ui.admin.rcp.product"/>
+ <unit version="1.0.0.v20100510-42A79oB5855K5E" id="org.eclipse.equinox.server.servletbridge.feature.group"/>
+ <unit version="1.0.0.v20100510-44DF8s734C48662444" id="org.eclipse.equinox.server.simple.feature.group"/>
<repository location="http://download.eclipse.org/eclipse/updates/3.6.x/"/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="org.eclipse.birt.feature.group" version="2.6.1.v20100709a-9iF7A8FGLY4z0pxX3ORrsdrp6JXb"/>
- <unit id="org.eclipse.datatools.connectivity.feature.feature.group" version="1.8.0.v201005280400-7C7b8cEt1ZvsifWcrT8a-F-sz05R"/>
- <unit id="org.eclipse.datatools.enablement.feature.feature.group" version="1.8.0.v201005280400-7J8x0BWwUK6x2yoco_A-q71HMuLt"/>
- <unit id="org.eclipse.datatools.sdk.feature.feature.group" version="1.8.0.v201005280400-7P9i0FDxNYrk4QYG-9qpz0N-vbEp"/>
- <unit id="org.eclipse.datatools.enablement.jdt.feature.feature.group" version="1.8.0.v201005280400-2-07w31211518181A"/>
- <unit id="org.eclipse.datatools.modelbase.feature.feature.group" version="1.8.0.v201005280400-77077CcNBGKBWJ_HWVi"/>
- <unit id="org.eclipse.datatools.enablement.apache.derby.feature.feature.group" version="1.8.1.v20100618-77778eBmKDNOMgJvJ8Of7QBR"/>
- <unit id="org.eclipse.draw2d.feature.group" version="3.6.0.v20100519-2050-45-7w3121163602336"/>
- <unit id="org.eclipse.gef.feature.group" version="3.6.0.v20100519-2050-777B-81A2Bz-69793A8B83447"/>
- <unit id="org.eclipse.zest.feature.group" version="1.2.0.v20100519-2050-678-8yE4F-8HAH4DFEF3447"/>
- <unit id="org.eclipse.uml2.feature.group" version="3.1.0.v201006071150"/>
- <unit id="org.eclipse.rse.feature.group" version="3.2.1.v201008191400-7L78FA-8wqbPcNj4qa8R0eViy7vZ"/>
+ <unit version="2.6.1.v20100709a-9iF7A8FGLY4z0pxX3ORrsdrp6JXb" id="org.eclipse.birt.feature.group"/>
+ <unit version="1.8.1.v20100618-7C7b8hEt1ZvtiLkdlO7BVoL_wm6" id="org.eclipse.datatools.connectivity.feature.feature.group"/>
+ <unit version="1.8.1.v20100618-7J8x7FBWwUL6z-2z-fcrYC2s55KI" id="org.eclipse.datatools.enablement.feature.feature.group"/>
+ <unit version="1.8.1.v20100618-7P9i7KFDxNYrp4cjPjqnPaRKxeyT" id="org.eclipse.datatools.sdk.feature.feature.group"/>
+ <unit version="1.8.1.v20100618-2-07w31211518181A" id="org.eclipse.datatools.enablement.jdt.feature.feature.group"/>
+ <unit version="1.8.1.v20100618-77078CcNBGKBZI_FcRd" id="org.eclipse.datatools.modelbase.feature.feature.group"/>
+ <unit version="1.8.1.v20100618-77778eBmKDNOMgJvJ8Of7QBR" id="org.eclipse.datatools.enablement.apache.derby.feature.feature.group"/>
+ <unit version="3.6.1.v20100908-1100-4507w31211A2403131" id="org.eclipse.draw2d.feature.group"/>
+ <unit version="3.6.1.v20100908-1100-777B181A3Bz-6B663E7974242" id="org.eclipse.gef.feature.group"/>
+ <unit version="1.2.0.v20100519-2050-67808yE5F-8HAH4HECF4242" id="org.eclipse.zest.feature.group"/>
+ <unit version="3.1.1.v201008191505" id="org.eclipse.uml2.feature.group"/>
+ <unit version="3.2.1.v201008191400-7L78FA-8wqbPcNj4qa8R0eViy7vZ" id="org.eclipse.rse.feature.group"/>
<repository location="http://download.eclipse.org/releases/helios/"/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="org.eclipse.jst.jee" version="1.0.301.v201007151900"/>
- <unit id="org.eclipse.wst.common.frameworks" version="1.2.0.v201003040800"/>
- <unit id="org.eclipse.wst.common.project.facet.ui" version="1.4.102.v201008170019"/>
- <unit id="org.eclipse.jst.jee.web" version="1.0.301.v201007070907"/>
- <unit id="org.eclipse.jst.common.fproj.enablement.jdt.feature.group" version="3.2.2.v201008170019-377AB8s73533J5J759F"/>
+ <unit version="1.0.301.v201007151900" id="org.eclipse.jst.jee"/>
+ <unit version="1.2.0.v201003040800" id="org.eclipse.wst.common.frameworks"/>
+ <unit version="1.4.102.v201008170019" id="org.eclipse.wst.common.project.facet.ui"/>
+ <unit version="1.0.301.v201007070907" id="org.eclipse.jst.jee.web"/>
+ <unit version="3.2.2.v201008170019-377AB8s73533J5J759F" id="org.eclipse.jst.common.fproj.enablement.jdt.feature.group"/>
- <unit id="org.eclipse.jst.ws.axis2tools.feature.feature.group" version="1.1.100.v201005241530-78-FF0DZRDKDDePSKwHj"/>
- <unit id="org.eclipse.jst.ws.cxf.feature.feature.group" version="1.0.2.v201008232129-7H777DFAKlRiOX8lGdRoz0878J"/>
- <unit id="org.eclipse.jpt.feature.feature.group" version="2.3.2.v201008242310-7N7UF75FD3wTgbUpoff0aT"/>
- <unit id="org.eclipse.wst.common.fproj.feature.group" version="3.2.2.v201008170019-377AB8s73533J5H335L"/>
- <unit id="org.eclipse.jst.enterprise_ui.feature.feature.group" version="3.2.2.v201008190400-7b7GHf2FSK2WBLQ2D-mrubYEOrRh"/>
- <unit id="org.eclipse.wst.web_ui.feature.feature.group" version="3.2.2.v201008100100-7O7CFbKEMf84nUlEJyX7-SPQjhYZ"/>
- <unit id="org.eclipse.wst.xml_ui.feature.feature.group" version="3.2.2.v201008170029-7H7AFUQDxumQGOpBqffOY2f1qxDZ"/>
- <unit id="org.eclipse.wst.xsl.feature.feature.group" version="1.1.2.v201009091745-7S7WFAPFIpS-1-NbCE6tnacCXKP"/>
- <unit id="org.eclipse.wst.jsdt.feature.feature.group" version="1.2.2.v201008170101-7C78FGMF9JgLWLMUUEMtXc"/>
- <unit id="org.eclipse.jsf.feature.feature.group" version="3.2.2.v201008231400-7E7I6F9JgLWLMUW3"/>
- <unit id="org.eclipse.jst.ws.jaxws.dom.feature.feature.group" version="1.0.0.v201005241530-5--AkF7B77NBZBgBg"/>
- <unit id="org.eclipse.jst.ws.jaxws.feature.feature.group" version="1.0.1.v201008232129-7E777CF8NcJSSK-UBTwXn"/>
- <unit id="org.eclipse.jst.enterprise_core.feature.feature.group" version="3.2.1.v201007070821-52FMTAkF7B77UBR7W98"/>
- <unit id="org.eclipse.jst.server_adapters.ext.feature.feature.group" version="3.2.2.v20100818b-777HFGRCcNBDiBjIbhBA8"/>
- <unit id="org.eclipse.jst.server_adapters.feature.feature.group" version="3.2.0.v201005241530-208Z7w31211419"/>
- <unit id="org.eclipse.jst.server_core.feature.feature.group" version="3.2.0.v201005241530-31FA28s73533C66"/>
- <unit id="org.eclipse.jst.server_ui.feature.feature.group" version="3.2.2.v20100908-7A5FEi9xFc7RCJMToAIOJC43A"/>
- <unit id="org.eclipse.jst.web_ui.feature.feature.group" version="3.2.2.v201008170029-7F77FJSC25Tkdy1nqglPjqLAoDgh"/>
- <unit id="org.eclipse.jsf.feature.source.feature.group" version="3.2.2.v201008231400-7E7I6F9JgLWLMUW3"/>
- <unit id="org.eclipse.wst.xml.xpath2.processor.feature.feature.group" version="1.1.5.v201009091745-67K2BgJ9DIAXCbBWJO"/>
- <unit id="org.eclipse.jst.webpageeditor.feature.feature.group" version="2.3.1.v20100906-4609oB5855L6N"/>
- <unit id="org.eclipse.wst.ws_wsdl15.feature.feature.group" version="1.5.300.v201005241450-2407w312116191741"/>
- <unit id="org.eclipse.wst.common_core.feature.feature.group" version="3.2.2.v201008091400-7B7DFElF7RZHOZJ6W0PsNJ"/>
- <unit id="org.eclipse.wst.common_ui.feature.feature.group" version="3.2.2.v201008091400-7C78FPhEdhO_mXde7kbap_K7X1Qt"/>
- <unit id="org.eclipse.wst.server_adapters.feature.feature.group" version="3.2.0.v201005241510-51EoAkF77g8HBSc"/>
- <unit id="org.eclipse.wst.server_core.feature.feature.group" version="3.2.2.v20100908-30F8V8s734C3I3K"/>
- <unit id="org.eclipse.wst.server_ui.feature.feature.group" version="3.2.2.v20100908-7B4FBrAtJb1nESKmCJHPGQ347"/>
- <unit id="org.eclipse.wst.web_core.feature.feature.group" version="3.2.2.v201008100100-7E7AFHwAJrn5PM15pUYBwJLkSG8j"/>
- <unit id="org.eclipse.wst.ws_ui.feature.feature.group" version="3.2.2.v201008211705-7I78FZFEtEoO2c5BlJ4jPNvNC-yS"/>
- <unit id="org.eclipse.wst.xml_core.feature.feature.group" version="3.2.2.v201008170029-7C7OFXYF7RZHQHI5PyJwPT"/>
+ <unit version="1.1.100.v201005241530-78-FF0DZRDKDDePSKwHj" id="org.eclipse.jst.ws.axis2tools.feature.feature.group"/>
+ <unit version="1.0.2.v201008232129-7H777DFAKlRiOX8lGdRoz0878J" id="org.eclipse.jst.ws.cxf.feature.feature.group"/>
+ <unit version="2.3.2.v201008242310-7N7UF75FD3wTgbUpoff0aT" id="org.eclipse.jpt.feature.feature.group"/>
+ <unit version="3.2.2.v201008170019-377AB8s73533J5H335L" id="org.eclipse.wst.common.fproj.feature.group"/>
+ <unit version="3.2.2.v201008190400-7b7GHf2FSK2WBLQ2D-mrubYEOrRh" id="org.eclipse.jst.enterprise_ui.feature.feature.group"/>
+ <unit version="3.2.2.v201008100100-7O7CFbKEMf84nUlEJyX7-SPQjhYZ" id="org.eclipse.wst.web_ui.feature.feature.group"/>
+ <unit version="3.2.2.v201008170029-7H7AFUQDxumQGOpBqffOY2f1qxDZ" id="org.eclipse.wst.xml_ui.feature.feature.group"/>
+ <unit version="1.1.2.v201009091745-7S7WFAPFIpS-1-NbCE6tnacCXKP" id="org.eclipse.wst.xsl.feature.feature.group"/>
+ <unit version="1.2.2.v201008170101-7C78FGMF9JgLWLMUUEMtXc" id="org.eclipse.wst.jsdt.feature.feature.group"/>
+ <unit version="3.2.2.v201008231400-7E7I6F9JgLWLMUW3" id="org.eclipse.jsf.feature.feature.group"/>
+ <unit version="1.0.0.v201005241530-5--AkF7B77NBZBgBg" id="org.eclipse.jst.ws.jaxws.dom.feature.feature.group"/>
+ <unit version="1.0.1.v201008232129-7E777CF8NcJSSK-UBTwXn" id="org.eclipse.jst.ws.jaxws.feature.feature.group"/>
+ <unit version="3.2.1.v201007070821-52FMTAkF7B77UBR7W98" id="org.eclipse.jst.enterprise_core.feature.feature.group"/>
+ <unit version="3.2.2.v20100818b-777HFGRCcNBDiBjIbhBA8" id="org.eclipse.jst.server_adapters.ext.feature.feature.group"/>
+ <unit version="3.2.0.v201005241530-208Z7w31211419" id="org.eclipse.jst.server_adapters.feature.feature.group"/>
+ <unit version="3.2.0.v201005241530-31FA28s73533C66" id="org.eclipse.jst.server_core.feature.feature.group"/>
+ <unit version="3.2.2.v20100908-7A5FEi9xFc7RCJMToAIOJC43A" id="org.eclipse.jst.server_ui.feature.feature.group"/>
+ <unit version="3.2.2.v201008170029-7F77FJSC25Tkdy1nqglPjqLAoDgh" id="org.eclipse.jst.web_ui.feature.feature.group"/>
+ <unit version="3.2.2.v201008231400-7E7I6F9JgLWLMUW3" id="org.eclipse.jsf.feature.source.feature.group"/>
+ <unit version="1.1.5.v201009091745-67K2BgJ9DIAXCbBWJO" id="org.eclipse.wst.xml.xpath2.processor.feature.feature.group"/>
+ <unit version="2.3.1.v20100906-4609oB5855L6N" id="org.eclipse.jst.webpageeditor.feature.feature.group"/>
+ <unit version="1.5.300.v201005241450-2407w312116191741" id="org.eclipse.wst.ws_wsdl15.feature.feature.group"/>
+ <unit version="3.2.2.v201008091400-7B7DFElF7RZHOZJ6W0PsNJ" id="org.eclipse.wst.common_core.feature.feature.group"/>
+ <unit version="3.2.2.v201008091400-7C78FPhEdhO_mXde7kbap_K7X1Qt" id="org.eclipse.wst.common_ui.feature.feature.group"/>
+ <unit version="3.2.0.v201005241510-51EoAkF77g8HBSc" id="org.eclipse.wst.server_adapters.feature.feature.group"/>
+ <unit version="3.2.2.v20100908-30F8V8s734C3I3K" id="org.eclipse.wst.server_core.feature.feature.group"/>
+ <unit version="3.2.2.v20100908-7B4FBrAtJb1nESKmCJHPGQ347" id="org.eclipse.wst.server_ui.feature.feature.group"/>
+ <unit version="3.2.2.v201008100100-7E7AFHwAJrn5PM15pUYBwJLkSG8j" id="org.eclipse.wst.web_core.feature.feature.group"/>
+ <unit version="3.2.2.v201008211705-7I78FZFEtEoO2c5BlJ4jPNvNC-yS" id="org.eclipse.wst.ws_ui.feature.feature.group"/>
+ <unit version="3.2.2.v201008170029-7C7OFXYF7RZHQHI5PyJwPT" id="org.eclipse.wst.xml_core.feature.feature.group"/>
<repository location="http://download.eclipse.org/webtools/repository/helios/"/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
<repository location="http://download.jboss.org/jbosstools/builds/staging/jbosstools-drools/all..."/>
</location>
<location includeAllPlatforms="false" includeMode="planner" type="InstallableUnit">
- <unit id="com.google.gdt.eclipse.suite.e36.feature.feature.group" version="1.3.3.v201006111317"/>
+ <unit version="1.3.3.v201006111317" id="com.google.gdt.eclipse.suite.e36.feature.feature.group"/>
<repository location="http://dl.google.com/eclipse/plugin/3.6/"/>
</location>
@@ -196,4 +195,4 @@
<feature id="org.mozilla.xpcom.feature"/>
</includeBundles>
<targetJRE path="org.eclipse.jdt.launching.JRE_CONTAINER/org.eclipse.jdt.internal.debug.ui.launcher.StandardVMType/JavaSE-1.6"/>
-</target>
+</target>
\ No newline at end of file
14 years, 3 months
JBoss Tools SVN: r25462 - trunk/build/target-platform.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-10-04 12:32:47 -0400 (Mon, 04 Oct 2010)
New Revision: 25462
Modified:
trunk/build/target-platform/target2p2mirrorXml.xsl
Log:
refactor for consistency
Modified: trunk/build/target-platform/target2p2mirrorXml.xsl
===================================================================
--- trunk/build/target-platform/target2p2mirrorXml.xsl 2010-10-04 16:32:31 UTC (rev 25461)
+++ trunk/build/target-platform/target2p2mirrorXml.xsl 2010-10-04 16:32:47 UTC (rev 25462)
@@ -13,7 +13,7 @@
<xsl:param name="verbose" select="'${verbose}'" as="xs:string"/>
<xsl:param name="followStrict" select="'${followStrict}'" as="xs:string"/>
- <xsl:param name="destination" select="'file:${repo.dir}'" as="xs:string"/>
+ <xsl:param name="destination" select="'file:${repoDir}'" as="xs:string"/>
<xsl:template match="target">
<project name="Download target platform" default="download.target.platform">
@@ -32,17 +32,17 @@
/abs/path/to/eclipse -vm /opt/jdk1.6.0/bin/java \
-nosplash -data /tmp/workspace -consolelog -application \
org.eclipse.ant.core.antRunner -f *.target.p2mirror.xml \
- -Ddebug=true -DfollowStrict=true -Drepo.dir=`pwd`/REPO/
+ -Ddebug=true -DfollowStrict=true -DrepoDir=`pwd`/REPO/
</echo>
</target>
- <target name="init" unless="repo.dir">
- <fail>Must set -Drepo.dir=/abs/path/to/download/artifacts/</fail>
+ <target name="init" unless="repoDir">
+ <fail>Must set -DrepoDir=/abs/path/to/download/artifacts/</fail>
</target>
<target name="download.target.platform" depends="init"
- description="Download from target platform definition" if="repo.dir">
+ description="Download from target platform definition" if="repoDir">
<property name="verbose" value="false" />
<property name="followStrict" value="false" />
- <echo level="info">Download features/plugins into ${repo.dir}</echo>
+ <echo level="info">Download features/plugins into ${repoDir}</echo>
<p2.mirror destination="{$destination}" verbose="{$verbose}">
<!-- should we add latestVersionOnly="true" to <slicingOptions> ? -->
<slicingOptions includeFeatures="true" followStrict="{$followStrict}"/>
14 years, 3 months
--- trunk/build/publishUpdateZipToStaging.sh 2010-10-04 18:57:44 UTC (rev 25465)
+++ trunk/build/publishUpdateZipToStaging.sh 2010-10-04 19:20:20 UTC (rev 25466)
@@ -1,11 +1,26 @@
-# Use this script to publisher a single update site zip via a Hudson job
+# Use this script to publish a single update site zip via a Hudson job
+if [[ $1 ]]; then
+ # specify job to publish on commandline
+ JOBNAMEREDUX=$1
+elif [[ ${JOB_NAME} ]]; then
+ # pull name of the job to publish from the name of the publisher job
+ JOBNAMEREDUX=${JOB_NAME/-publish}
+else
+ echo "Must run from Hudson or manually specify job name"
+ echo "(for offline testing), eg., $0 jbosstools-teiid-designer"
+ exit 1
+fi
+
+if [[ $DESTINATION == "" ]]; then DESTINATION="tools@filemgmt.jboss.org:/downloads_htdocs/tools"; fi
+
# get zip name from zip.list.txt
-path=$(wget -q http://download.jboss.org/jbosstools/builds/staging/${JOB_NAME}/logs/zip.... -O - | egrep -- "-Update-" | head -1 | sed "s#,\\\\##");
+path=$(wget -q http://download.jboss.org/jbosstools/builds/staging/${JOBNAMEREDUX}/logs/... -O - | egrep -- "-Update-" | head -1 | sed "s#,\\\\##");
-# get zip to local
-rsync -arzq tools@filemgmt.jboss.org:/downloads_htdocs/tools/builds/staging/${JOB_NAME}/${path} .
+echo "Fetch ${path} as ${JOBNAMEREDUX}-Update.zip"
+# to test locally, may need to use --protocol=29 and -P instead of -q
+date; rsync -arzq --rsh=ssh ${DESTINATION}/builds/staging/${JOBNAMEREDUX}/${path} ${JOBNAMEREDUX}-Update.zip
-# push renamed zip to remote
-cd ${path%/*}; rsync -arzq ${path##*/} tools@filemgmt.jboss.org:/downloads_htdocs/tools/updates/staging/${JOB_NAME}-Update.zip
-
+echo "Publish ${path} as ${JOBNAMEREDUX}-Update.zip"
+# to test locally, may need to use --protocol=29 and -P instead of -q
+date; rsync -arzq --rsh=ssh ${JOBNAMEREDUX}-Update.zip ${DESTINATION}/updates/staging/
14 years, 3 months
JBoss Tools SVN: r25465 - trunk/build.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-10-04 14:57:44 -0400 (Mon, 04 Oct 2010)
New Revision: 25465
Modified:
trunk/build/publishUpdateZipToStaging.sh
Log:
https://jira.jboss.org/browse/JBDS-1349 new single-serving update site zip publisher, for on demand use (by Hudson)
Modified: trunk/build/publishUpdateZipToStaging.sh
===================================================================